==> haskell-mtl-2.2.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mtl
version: 2.2.1
id: mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
key: mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
license: BSD3
maintainer: Edward Kmett <ekmett@gmail.com>
homepage: http://github.com/ekmett/mtl
synopsis: Monad classes, using functional dependencies
description:
    Monad classes using functional dependencies, with instances
    for various monad transformers, inspired by the paper
    /Functional Programming with Overloading and Higher-Order Polymorphism/,
    by Mark P Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
category: Control
author: Andy Gill
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Except
    Control.Monad.Identity Control.Monad.List Control.Monad.RWS
    Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict
abi: dff2eda61fc7cfa040a2eb3f0192c69a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/mtl-2.2.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/mtl-2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/mtl-2.2.1
hs-libraries: HSmtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
depends:
    base-4.10.0.0 transformers-0.5.2.0
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
haddock-interfaces: /usr/share/doc/haskell-mtl/html/mtl.haddock
haddock-html: /usr/share/doc/haskell-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mtl-2.2.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mtl
version: 2.2.1
id: mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
key: mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
license: BSD3
maintainer: Edward Kmett <ekmett@gmail.com>
homepage: http://github.com/ekmett/mtl
synopsis: Monad classes, using functional dependencies
description:
    Monad classes using functional dependencies, with instances
    for various monad transformers, inspired by the paper
    /Functional Programming with Overloading and Higher-Order Polymorphism/,
    by Mark P Jones, in /Advanced School of Functional Programming/, 1995
    (<http://web.cecs.pdx.edu/~mpj/pubs/springschool.html>).
category: Control
author: Andy Gill
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Except
    Control.Monad.Identity Control.Monad.List Control.Monad.RWS
    Control.Monad.RWS.Class Control.Monad.RWS.Lazy
    Control.Monad.RWS.Strict Control.Monad.Reader
    Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict
abi: 1e76d6f7019a4b5c8c222b2fbbb06681
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mtl-2.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/mtl-2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/mtl-2.2.1
hs-libraries: HSmtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
depends:
    base-4.10.1.0 transformers-0.5.2.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
haddock-interfaces: /usr/share/doc/haskell-mtl/html/mtl.haddock
haddock-html: /usr/share/doc/haskell-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
